@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-from textrpg import Char, story, ask
-from textrpg import save
-
+from rpg_lib.textrpg import Char, story, ask, give_exp
+from rpg_lib.textrpg import save
 
 name = ask("What's your name?")
 
@@ -15,7 +14,7 @@ char1 = Char(source="tag:1w6.org,2008:" + name)
 # won: If we won
 # Diff: By how much we won or lost (always positive). 
 
-story("...Press enter to read on...")
+story("...Press enter to read the next line...")
 
 story('''
 Where the sun doesn't shine, 
