@@ -12,8 +12,9 @@ Plans:
     - char.compete(other, skill_name) -> See who wins and by how much. 
 
 Ideas: 
-    - Lazy loading modules, to be able to print stuff at once without having to print before the imports.
+    - Lazy loading modules, to be able to print stuff at once without having to print before the imports. 
     - Add getting experience for groups and show the chars together (only one experience header instead of one per char). 
+    - Being able to press "pause" when using autoscrolling output. 
 
 
 Basic design principles for the scripting language: 
@@ -92,6 +93,7 @@ __url__       = 'http://rpg-1d6.sf.net'
 
 __version__   = '0.1' 
 
+import sys
 from textrpg_1d6 import Char as ews_char
 from time import sleep # for autoscrolling
 
@@ -100,28 +102,119 @@ from time import sleep # for autoscrolling
 class UserInteraction(object): 
     """Basic user interaction: Showing and asking things."""
     def __init__(self, *args, **kwds): 
+	self.line_length = 80 #: The maximum length of story lines. 
+	self.line_wait = 0.4
+	self.char_wait = 0.05
         super(UserInteraction, self).__init__(*args, **kwds)
+	
         
     def ask(self, question=None, *args, **kwds): 
         """Ask a question.
         
-        Note: Not console based implementations will want to overwrite this. """
+        Note: Not console based implementations will want to overwrite this. 
+	
+	Plans: 
+		- ask(question=None, default=0, *answers, **kwds) - usage: ask("why", "because", "it's how it is", "I don't know", default=2) -> default capitalized, rest small print. 
+	"""
         if question is not None: 
 	    sleep(0.01)
             return raw_input(_(question) + " ")
+
+    def split_diag(self, text, line_length = None, localize=True, autoscroll=False, line_beginning = "", *args, **kwds): 
+	"""Print a dialog in single lines split at word borders. 
+	
+	@param text: The text to output. 
+	@param line_length: Maximum length of a line. 
+	
+	"""
+	# Split the text by words to output at most self.line_length chars per line. 
+	if line_length is None: 
+	    line_length = self.line_length
+	text_to_print = ""
+	# Preserve leading spaces. 
+	if text: 
+	    while text[0] == " ": 
+		text_to_print += " "
+		text = text[1:]
+	# Print as many words as possible without breaking the max line width. 
+	for j in text.split(): 
+	    if len(line_beginning) + len(text_to_print) + len(j) >= line_length: 
+		self.diag(line_beginning + text_to_print, localize=localize, autoscroll=autoscroll, *args, **kwds)
+		# If j > self.line_length -> split j and use only the remaining rest as default, printing all else directly. 
+		if len(line_beginning) + len(j) > self.line_length: 
+		    while j[self.line_length - len(line_beginning):]: 
+			self.diag(line_beginning + j[:self.line_length - len(line_beginning)], localize=localize, autoscroll=autoscroll, *args, **kwds)
+			j = j[self.line_length - len(line_beginning):]
+		text_to_print = j
+	    else: 
+		# if we already have text_to_print, add j with a space. 
+		if text_to_print: 
+		    text_to_print += " " + j
+		else: 
+		    text_to_print = j
+	# Print the last line of this dialog. 
+	self.diag(line_beginning + text_to_print, localize=localize, autoscroll=autoscroll, *args, **kwds)
     
-    def diag(self, data, localize=True, autoscroll=False, *args, **kwds):
+    def diag(self, data, localize=True, autoscroll=False, line_wait = None, char_wait = None, relative_speed = 1, end_with_linebreak = True, position_in_line = 0, *args, **kwds):
+	""" Print a dialog line. 
+	
+	@param line_wait: The time to wait at linebreaks before continuing with the text. 
+	@param char_wait: The time to wait per char before printing the next char. 
+	@param relative_speed: The relative speed of this dialog compared to others. - Limitation: Speed can only be adjusted for whole lines! 
+	@param autoscroll: If diag should output char by char (True) or wait for user input for each lines (False). 
+	@param end_with_linebreak: If there should be a linebreak at the end (True), or if the next dialog should write on the same line (False). 
+	@param position_in_line: Where in the text line the cursor should be positioned when writing. 
+	"""
+	# If the method doesn't get line_wait and/or char_wait, it uses the default values for the UI. 
+	# With this we can customize the speed of the output. 
+	if line_wait is None: 
+	    line_wait = self.line_wait
+	if char_wait is None: 
+	    char_wait = self.char_wait
+
+	# Now adjust the speed by the relative speed: 
+	if relative_speed != 1: 
+	    char_wait *= relative_speed
+	    line_wait *= relative_speed
+
+	# Localize the text
         if localize: 
             text = _(data)
         else: text = data 
     
+	# And output it. 
+	# If we have no autoscrolling, we just output the text. 
         if not autoscroll: 
             raw_input(text)
+	
+	# If we have autoscrolling, we print it char by char. 
+	# Limitation: This looks really dumb, if the text is longer than one line. 
         else: 
-            print text
+	    if text: 
+		sys.stdout.write('\033[' + str(position_in_line) + 'G')
+                sys.stdout.flush()
+	    else: 
+		self.diag("...press enter to read on...") # press enter to read on at each empty line, so readers can rest. 
+                # clear the line after the user pressed enter.
+                sys.stdout.write('\033[2A\033[' + str(position_in_line) + 'G')
+		for i in range(len(_("...press enter to read on..."))): 
+		    sys.stdout.write(" ")
+                sys.stdout.flush()
+		#sleep(line_wait)
             # First sleep 1/10th second. This ensures that the text gets shown before sleeping.
-            sleep(0.1)
-            sleep((len(text) - 1)*0.1)
+            sleep(char_wait)
+	    # If we have text, wait one 10th of a second per char. 
+	    for i in text: 
+		# load the current cursor position
+		sys.stdout.write(i)
+                sys.stdout.flush()
+		sleep(char_wait)
+	
+	# If we want a linebreak at the end, add it. 
+	if end_with_linebreak: 
+	    # Move back after the last char on the last line. 
+	    sys.stdout.write("\n")
+            sys.stdout.flush()
 
 class Dialogs(object): 
     """Basic dialogs. 
@@ -182,11 +275,11 @@ class Char(ews_char, UserInteraction, Dialogs):
         super(Char, self).__init__(template=template, *args, **kwds)
         self.battle_diff_treshold = 4 #: The treshold of the char below which no hit is scored. 
     
-    def say(self, data): 
+    def say(self, data, *args, **kwds): 
         """Say something -> Show that the char says it."""
         data = _(data)
         for i in data.split("\n"): 
-            self.diag(self.name + ': ' + i, localize=False)
+            self.split_diag(i, localize=False, line_beginning = self.name + ': ', *args, **kwds)
     
     def ask(self, data, localize=False, *args, **kwds): 
         """Say something -> Show that the char says it."""
@@ -195,7 +288,7 @@ class Char(ews_char, UserInteraction, Dialogs):
             self.diag(self.name + ': ' + i, localize=localize, *args, **kwds)
         return super(Char, self).ask(self.name + ': ' + data.split("\n")[-1], *args, **kwds)
     
-    def act(self, data): 
+    def act(self, data, *args, **kwds): 
         """Do something -> Show that the char does it in the style "<name> walks away.".
         
         Usage: 
@@ -205,7 +298,7 @@ class Char(ews_char, UserInteraction, Dialogs):
         """
         data = _(data)
         for i in data.split("\n"): 
-            self.diag(self.name + ' ' + i, localize=False)
+            self.diag(self.name + ' ' + i, localize=False, *args, **kwds)
         
     def compete_skill(self, other, skill_name, self_mods=[], other_mods=[]): 
         """Compete with the other char in the specified skill. 
@@ -533,9 +626,21 @@ class MissingScriptingFunction(Exception):
 
 ### Functions ###
 
-def _(text):
-    '''String function to allow localizing later on. '''
-    return str(text)
+de_DE = {
+#"""...press enter to read on...""": """...zum weiterlesen Enter drücken...""",
+}
+
+def _(text, locale="en_EN", locales={"de_DE": de_DE}):
+    '''String function to allow localizing later on. 
+    
+    @return: A localized string. '''
+    # TODO: Localize cleanly - this is but a test. 
+    if text in locales["de_DE"]: 
+	return locales["de_DE"][text]
+    else: 
+	return str(text)
+
+
 
 ## Functions needed to be implemented in EVERY simple rpg scripting module (changing their effect for all places where they get used can only be done in the Story class) ###
 def ask(question, *args, **kwds): 
