@@ -49,6 +49,9 @@ Basic design principles for the scripting language:
 
 The code for the TextRPG can be found at U{http://dreehg.org/ArneBab/textrpg}
 
+Shell escape codes: 
+    - print 'abc';print '\033[2A';sleep(0.3);print 'abcd'; -> die geschriebene Zeile ersetzen. 
+
 """
 
 try: 
@@ -56,20 +59,20 @@ try:
 except: 
     from rpg_lib.anyrpg import __copyright__, __url__, __author__
 
-__version__   = '0.4.4' 
+__version__   = '0.4.6' 
 # __date__      = '7th March 2007' 
 
 
-print "...Loading rpg library..."
+#print "...Loading rpg library..."
 
 
-try: 
+try: # Get the modules by relative path
     # AnyRPG classes
     from anyrpg import Char
     from anyrpg import Story as any_story
     # AnyRPG function for localizing. 
     from anyrpg import _
-except: 
+except: # get the modules by absolute path
     # AnyRPG classes
     from rpg_lib.anyrpg import Char
     from rpg_lib.anyrpg import Story as any_story
@@ -77,29 +80,27 @@ except:
     from rpg_lib.anyrpg import _
 
 
-# Changing things. I want to display "..." in front of every blank story line. 
+# Changing things. I want to tell stories in lines, broken at word borders, so I want story() to use the split diag. 
 
 class Story(any_story): 
     def __init__(self, *args, **kwds): 
         super(Story, self).__init__(*args, **kwds)
     
-    def story(self, data=None, *args, **kwds): 
+    def story(self, data=None, autoscroll=False, *args, **kwds): 
         """Tell a part of the story.
         
         Overridden to show "..." instead of blank lines (override commented out). """
         if data is not None: 
             data = _(data)
             for i in data.split("\n"): 
-                #if i.rstrip() == "": 
-                #    self.diag("...", localize=False)
-                #else: 
-                    self.diag(i, localize=False)
+		self.split_diag(i, localize=False, autoscroll=True, *args, **kwds)
         
 
 # Define helper functions. 
 story_helper = Story()
 
 ### Lines needed in EVERY simple rpg scripting module (changing their effect for all places where they get used can only be done in the Story class) ###
+
 def ask(question, *args, **kwds): 
     """Ask a question. 
     @return: The answer of the user."""
@@ -134,15 +135,15 @@ def battle(me, other, *args, **kwds):
 ### Test story lines ###
 
 def greet(char): 
-    diag("Old man: Welcome traveller. You've come to the right place to learn about your heritage.")
-    diag("Sadly you aren' well liked around here.")
-    diag("Heges for example didn't like your father too much.")
-    diag("Oh well, that was an understatment. You should better prepare yourself to face him. I think he'd love to see your face in the mud. Here's my knife. I like fights to be fair.")
-    diag("...")
-    diag("You say you don't know who we think you are?")
-    diag("Well, at least tell me your name then, and I'll tell you a bit about your father, after you won.")
+    story("Old man: Welcome traveller. You've come to the right place to learn about your heritage.")
+    story("Sadly you aren' well liked around here.")
+    story("Heges for example didn't like your father too much.")
+    story("""Oh well, that was an understatment. You should better prepare yourself to face him. I think he'd love to see your face in the mud. Here's my knife. I like fights to be fair.
+""")
+    story("You say you don't know who we think you are?")
+    story("Well, at least tell me your name then, and I'll tell you a bit about your father, after you won.")
     char.name = raw_input("My Name: ")
-    diag("You've got a nice name, " + char.name + ". Good luck!")
+    story("You've got a nice name, " + char.name + ". Good luck!")
 
 
 if __name__ == "__main__": 
@@ -154,13 +155,13 @@ if __name__ == "__main__":
     choss.name = "Hegen"
     won = battle(char, choss)
     if won: 
-        diag(char.name + " won the fight.")
+        story(char.name + " won the fight.")
     else: 
-        diag(choss.name + " won the fight.")
+        story(choss.name + " won the fight.")
     give_exp(char, 3)
     choss.upgrade(3)
     if won: 
-        diag("Well done " + char.name + ". I knew my trust in you was well placed. Now about your father...")
+        story("Well done " + char.name + ". I knew my trust in you was well placed. Now about your father...")
     else: 
-        diag("I didn't expect you to lose to him. Well, fate is a harsh teacher. Better luck next time!")
+        story("I didn't expect you to lose to him. Well, fate is a harsh teacher. Better luck next time!")
     
